Arguments
- physeq
(required) A
phyloseq-classobject obtained using thephyloseqpackage.- rank_1
(character or integer) Define the first taxonomic rank as the number or the name of the column in tax_table slot.
- rank_2
(character or integer) Define the second taxonomic rank as the number or the name of the column in tax_table slot.
- suffix_1
(character, default "_1") A suffix to add to rank_1 values.
- suffix_2
(character, default "_2") A suffix to add to rank_2 values.